@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
-/* 
+/*
  * LDIF importer.  LDIF is the file format of an exported Netscape
  * addressbook.
  *
@@ -22,11 +22,10 @@
 #include <ctype.h>
 #include <string.h>
 
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 
-#include <gtk/gtkvbox.h>
-
 #include <libebook/e-book.h>
 #include <libedataserverui/e-source-selector.h>
 
@@ -116,93 +115,6 @@ ldif_fields[] = {
 };
 static int num_ldif_fields = sizeof(ldif_fields) / sizeof (ldif_fields[0]);
 
-static unsigned char base64_rank[256] = {
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255, 62,255,255,255, 63,
-	 52, 53, 54, 55, 56, 57, 58, 59, 60, 61,255,255,255,  0,255,255,
-	255,  0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14,
-	 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25,255,255,255,255,255,
-	255, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
-	 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-	255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
-};
-
-/**
- * base64_decode_step: decode a chunk of base64 encoded data
- * @in: input stream
- * @len: max length of data to decode
- * @out: output stream
- * @state: holds the number of bits that are stored in @save
- * @save: leftover bits that have not yet been decoded
- *
- * Decodes a chunk of base64 encoded data
- **/
-static int
-base64_decode_step(unsigned char *in, int len, unsigned char *out, int *state, unsigned int *save)
-{
-	register unsigned char *inptr, *outptr;
-	unsigned char *inend, c;
-	register unsigned int v;
-	int i;
-
-	inend = in+len;
-	outptr = out;
-
-	/* convert 4 base64 bytes to 3 normal bytes */
-	v=*save;
-	i=*state;
-	inptr = in;
-	while (inptr<inend) {
-		c = base64_rank[*inptr++];
-		if (c != 0xff) {
-			v = (v<<6) | c;
-			i++;
-			if (i==4) {
-				*outptr++ = v>>16;
-				*outptr++ = v>>8;
-				*outptr++ = v;
-				i=0;
-			}
-		}
-	}
-
-	*save = v;
-	*state = i;
-
-	/* quick scan back for '=' on the end somewhere */
-	/* fortunately we can drop 1 output char for each trailing = (upto 2) */
-	i=2;
-	while (inptr>in && i) {
-		inptr--;
-		if (base64_rank[*inptr] != 0xff) {
-			if (*inptr == '=')
-				outptr--;
-			i--;
-		}
-	}
-
-	/* if i!= 0 then there is a truncation error! */
-	return outptr-out;
-}
-
-static int
-base64_decode_simple (char *data, int len)
-{
-	int state = 0;
-	unsigned int save = 0;
-
-	return base64_decode_step ((unsigned char *)data, len,
-				   (unsigned char *)data, &state, &save);
-}
-
 static GString *
 getValue( char **src )
 {
@@ -224,11 +136,14 @@ getValue( char **src )
 	}
 
 	if (need_base64) {
-		int new_len;
-		/* it's base64 encoded */
-		dest = g_string_erase (dest, 0, 2);
-		new_len = base64_decode_simple (dest->str, strlen (dest->str));
-		dest = g_string_truncate (dest, new_len);
+		guchar *data;
+		gsize length;
+
+		/* XXX g_string_assign_len() would be nice here */
+		data = g_base64_decode (dest->str + 2, &length);
+		g_string_truncate (dest, 0);
+		g_string_append_len (dest, (gchar *) data, length);
+		g_free (data);
 	}
 
 	*src = s;
@@ -239,7 +154,7 @@ getValue( char **src )
 static void
 populate_contact_address (EContactAddress *address, char *attr, char *value)
 {
-	if (!g_ascii_strcasecmp (attr, "locality") || 
+	if (!g_ascii_strcasecmp (attr, "locality") ||
 	    !g_ascii_strcasecmp (attr, "l") ||
 	    !g_ascii_strcasecmp (attr, "mozillaHomeLocalityName"))
 		address->locality = g_strdup (value);
@@ -263,7 +178,7 @@ populate_contact_address (EContactAddress *address, char *attr, char *value)
 			address->ext = g_strconcat (temp, ",\n", value, NULL);
 			g_free (temp);
 		}
-		else { 
+		else {
 			address->ext = g_strdup (value);
 		}
 	}
@@ -293,8 +208,8 @@ populate_contact_address (EContactAddress *address, char *attr, char *value)
 }
 
 static gboolean
-parseLine (LDIFImporter *gci, EContact *contact, 
-	   EContactAddress *work_address, EContactAddress *home_address, 
+parseLine (LDIFImporter *gci, EContact *contact,
+	   EContactAddress *work_address, EContactAddress *home_address,
 	   char **buf)
 {
 	char *ptr;
@@ -455,7 +370,7 @@ getNextLDIFEntry(LDIFImporter *gci, FILE *f )
 	    work_address->code || work_address->region || work_address->street) {
 		e_contact_set (contact, E_CONTACT_ADDRESS_WORK, work_address);
 	}
-	if (home_address->locality || home_address->country || home_address->ext || 
+	if (home_address->locality || home_address->country || home_address->ext ||
 	    home_address->code || home_address->region || home_address->street) {
 		e_contact_set (contact, E_CONTACT_ADDRESS_HOME, home_address);
 	}
@@ -503,7 +418,7 @@ resolve_list_card (LDIFImporter *gci, EContact *contact)
 
 			email_attrs = g_list_append (email_attrs, attr);
 		}
-	}		
+	}
 	e_contact_set_attributes (contact, E_CONTACT_EMAIL, email_attrs);
 
 	g_list_foreach (email, (GFunc) g_free, NULL);
@@ -598,14 +513,14 @@ ldif_getwidget(EImport *ei, EImportTarget *target, EImportImporter *im)
 {
 	GtkWidget *vbox, *selector;
 	ESource *primary;
-	ESourceList *source_list;	
+	ESourceList *source_list;
 
 	/* FIXME Better error handling */
 	if (!e_book_get_addressbooks (&source_list, NULL))
 		return NULL;
 
 	vbox = gtk_vbox_new (FALSE, FALSE);
-	
+
 	selector = e_source_selector_new (source_list);
 	e_source_selector_show_selection (E_SOURCE_SELECTOR (selector), FALSE);
 	gtk_box_pack_start (GTK_BOX (vbox), selector, FALSE, TRUE, 6);
@@ -659,12 +574,6 @@ ldif_supported(EImport *ei, EImportTarget *target, EImportImporter *im)
 	return FALSE;
 }
 
-static void
-free_dn_hash(void *k, void *v, void *d)
-{
-	g_free(k);
-}
-
 static void
 ldif_import_done(LDIFImporter *gci)
 {
@@ -677,7 +586,6 @@ ldif_import_done(LDIFImporter *gci)
 	g_slist_foreach(gci->list_contacts, (GFunc) g_object_unref, NULL);
 	g_slist_free(gci->contacts);
 	g_slist_free(gci->list_contacts);
-	g_hash_table_foreach(gci->dn_contact_hash, free_dn_hash, NULL);
 	g_hash_table_destroy(gci->dn_contact_hash);
 
 	e_import_complete(gci->import, gci->target);
@@ -723,7 +631,10 @@ ldif_import(EImport *ei, EImportTarget *target, EImportImporter *im)
 	fseek(file, 0, SEEK_END);
 	gci->size = ftell(file);
 	fseek(file, 0, SEEK_SET);
-	gci->dn_contact_hash = g_hash_table_new(g_str_hash, g_str_equal);
+	gci->dn_contact_hash = g_hash_table_new_full (
+		g_str_hash, g_str_equal,
+		(GDestroyNotify) g_free,
+		(GDestroyNotify) NULL);
 
 	e_book_open(gci->book, FALSE, NULL);
 
