@@ -35,7 +35,6 @@
 #include <libgnomeui/gnome-dialog-util.h>
 #include <libgnomeui/gnome-uidefs.h>
 
-#include <e-util/e-icon-factory.h>
 #include <libecal/e-cal-time-util.h>
 #include <libecal/e-cal-component.h>
 
@@ -1384,19 +1383,18 @@ static gboolean
 tray_icon_blink_cb (gpointer data)
 {
 	static gboolean tray_blink_state = FALSE;
-	GdkPixbuf *pixbuf;
+	const gchar *icon_name;
 
 	tray_blink_countdown--;
 	tray_blink_state = !tray_blink_state;
 
-	pixbuf = e_icon_factory_get_icon  ((tray_blink_state || tray_blink_countdown <= 0)?
-					   "stock_appointment-reminder-excl" :
-					   "stock_appointment-reminder",
-					   E_ICON_SIZE_LARGE_TOOLBAR);
+	if (tray_blink_state || tray_blink_countdown <= 0)
+		icon_name = "stock_appointment-reminder-excl";
+	else
+		icon_name = "stock_appointment-reminder";
 
 	if (tray_icon)
-		gtk_status_icon_set_from_pixbuf (tray_icon, pixbuf);
-	g_object_unref (pixbuf);
+		gtk_status_icon_set_from_icon_name (tray_icon, icon_name);
 
 	if (tray_blink_countdown <= 0)
 		tray_blink_id = -1;
@@ -1480,7 +1478,8 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	/* create the tray icon */
 	if (tray_icon == NULL) {
 		tray_icon = gtk_status_icon_new ();
-		gtk_status_icon_set_from_pixbuf (tray_icon, e_icon_factory_get_icon ("stock_appointment-reminder", E_ICON_SIZE_LARGE_TOOLBAR));
+		gtk_status_icon_set_from_icon_name (
+			tray_icon, "stock_appointment-reminder");
 		g_signal_connect (G_OBJECT (tray_icon), "activate",
 				  G_CALLBACK (icon_activated), NULL);
 		g_signal_connect (G_OBJECT (tray_icon), "popup-menu",
