@@ -1,7 +1,7 @@
 /* Evolution calendar - Data model for ETable
  *
- * Copyright (C) 2000 Ximian, Inc.
- * Copyright (C) 2000 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Rodrigo Moya <rodrigo@ximian.com>
  *
@@ -46,8 +46,8 @@ typedef enum {
 	E_CAL_MODEL_TASKS_FIELD_PRIORITY,
 	E_CAL_MODEL_TASKS_FIELD_STATUS,
 	E_CAL_MODEL_TASKS_FIELD_URL,
-	E_CAL_MODEL_TASKS_FIELD_LAST,
-	E_CAL_MODEL_TASKS_FIELD_STRIKEOUT /* it's another virtual readonly column */
+	E_CAL_MODEL_TASKS_FIELD_STRIKEOUT, /* it's another virtual readonly column */
+	E_CAL_MODEL_TASKS_FIELD_LAST
 } ECalModelTasksField;
 
 typedef struct {
