@@ -422,12 +422,6 @@ ecalp_standard_menu_factory (EPopup *ecalp, void *data)
 				GAppInfo *app = l->data;
 				EPopupItem *item;
 
-				if (!g_app_info_should_show (app)) {
-					g_object_unref (app);
-					l->data = NULL;
-					continue;
-				}
-
 				item = g_malloc0(sizeof(*item));
 				item->type = E_POPUP_ITEM;
 				item->path = g_strdup_printf("99.object.%02d", i);
