@@ -3,7 +3,7 @@
  *
  * Author: Mike Kestner  <mkestner@ximian.com>
  *
- * Copyright (C) 2003 Ximian Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -21,8 +21,8 @@
  */
 
 #include <config.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkcelleditable.h>
 #include <libebook/e-destination.h>
 #include <libedataserverui/e-name-selector-entry.h>
 
