@@ -1,13 +1,13 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
-/* 
- * Author : 
+/*
+ * Author :
  *  Rodrigo Moya <rodrigo@ximian.com>
  *
- * Copyright 2003, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -44,7 +44,7 @@ e_week_view_config_set_property (GObject *object, guint property_id, const GValu
 	EWeekViewConfig *view_config;
 
 	view_config = E_WEEK_VIEW_CONFIG (object);
-	
+
 	switch (property_id) {
 	case PROP_VIEW:
 		e_week_view_config_set_view (view_config, g_value_get_object (value));
@@ -61,7 +61,7 @@ e_week_view_config_get_property (GObject *object, guint property_id, GValue *val
 	EWeekViewConfig *view_config;
 
 	view_config = E_WEEK_VIEW_CONFIG (object);
-	
+
 	switch (property_id) {
 	case PROP_VIEW:
 		g_value_set_object (value, e_week_view_config_get_view (view_config));
@@ -78,7 +78,7 @@ e_week_view_config_dispose (GObject *object)
 	EWeekViewConfig *view_config = E_WEEK_VIEW_CONFIG (object);
 
 	e_week_view_config_set_view (view_config, NULL);
-	
+
 	if (G_OBJECT_CLASS (e_week_view_config_parent_class)->dispose)
 		G_OBJECT_CLASS (e_week_view_config_parent_class)->dispose (object);
 }
@@ -88,11 +88,11 @@ e_week_view_config_finalize (GObject *object)
 {
 	EWeekViewConfig *view_config = E_WEEK_VIEW_CONFIG (object);
 	EWeekViewConfigPrivate *priv;
-	
+
 	priv = view_config->priv;
 
 	g_free (priv);
-	
+
 	if (G_OBJECT_CLASS (e_week_view_config_parent_class)->finalize)
 		G_OBJECT_CLASS (e_week_view_config_parent_class)->finalize (object);
 }
@@ -102,7 +102,7 @@ e_week_view_config_class_init (EWeekViewConfigClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 	GParamSpec *spec;
-	
+
 	/* Method override */
 	gobject_class->set_property = e_week_view_config_set_property;
 	gobject_class->get_property = e_week_view_config_get_property;
@@ -125,14 +125,14 @@ EWeekViewConfig *
 e_week_view_config_new (EWeekView *week_view)
 {
 	EWeekViewConfig *view_config;
-	
+
 	view_config = g_object_new (e_week_view_config_get_type (), "view", week_view, NULL);
 
 	return view_config;
 }
 
 EWeekView *
-e_week_view_config_get_view (EWeekViewConfig *view_config) 
+e_week_view_config_get_view (EWeekViewConfig *view_config)
 {
 	EWeekViewConfigPrivate *priv;
 
@@ -140,34 +140,14 @@ e_week_view_config_get_view (EWeekViewConfig *view_config)
 	g_return_val_if_fail (E_IS_WEEK_VIEW_CONFIG (view_config), NULL);
 
 	priv = view_config->priv;
-	
+
 	return priv->view;
 }
 
 static void
-set_timezone (EWeekView *week_view) 
+set_week_start (EWeekView *week_view)
 {
-	icaltimezone *zone;
-	
-	zone = calendar_config_get_icaltimezone ();	
-	e_calendar_view_set_timezone (E_CALENDAR_VIEW (week_view), zone);
-}
-
-static void
-timezone_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
-{
-	EWeekViewConfig *view_config = data;
-	EWeekViewConfigPrivate *priv;
-	
-	priv = view_config->priv;
-	
-	set_timezone (priv->view);
-}
-
-static void
-set_week_start (EWeekView *week_view) 
-{
-	int week_start_week;	
+	int week_start_week;
 
 	week_start_week = calendar_config_get_week_start_day ();
 
@@ -182,14 +162,14 @@ week_start_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointe
 {
 	EWeekViewConfig *view_config = data;
 	EWeekViewConfigPrivate *priv;
-	
+
 	priv = view_config->priv;
-	
+
 	set_week_start (priv->view);
 }
 
 static void
-set_twentyfour_hour (EWeekView *week_view) 
+set_twentyfour_hour (EWeekView *week_view)
 {
 	gboolean use_24_hour;
 
@@ -203,14 +183,14 @@ twentyfour_hour_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gp
 {
 	EWeekViewConfig *view_config = data;
 	EWeekViewConfigPrivate *priv;
-	
+
 	priv = view_config->priv;
-	
+
 	set_twentyfour_hour (priv->view);
 }
 
 static void
-set_show_event_end (EWeekView *week_view) 
+set_show_event_end (EWeekView *week_view)
 {
 	gboolean show_event_end;
 
@@ -224,14 +204,14 @@ show_event_end_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpo
 {
 	EWeekViewConfig *view_config = data;
 	EWeekViewConfigPrivate *priv;
-	
+
 	priv = view_config->priv;
-	
+
 	set_show_event_end (priv->view);
 }
 
 static void
-set_compress_weekend (EWeekView *week_view) 
+set_compress_weekend (EWeekView *week_view)
 {
 	gboolean compress_weekend;
 
@@ -245,29 +225,29 @@ compress_weekend_changed_cb (GConfClient *client, guint id, GConfEntry *entry, g
 {
 	EWeekViewConfig *view_config = data;
 	EWeekViewConfigPrivate *priv;
-	
+
 	priv = view_config->priv;
-	
+
 	set_compress_weekend (priv->view);
 }
 
 void
-e_week_view_config_set_view (EWeekViewConfig *view_config, EWeekView *week_view) 
+e_week_view_config_set_view (EWeekViewConfig *view_config, EWeekView *week_view)
 {
 	EWeekViewConfigPrivate *priv;
 	guint not;
 	GList *l;
-	
+
 	g_return_if_fail (view_config != NULL);
 	g_return_if_fail (E_IS_WEEK_VIEW_CONFIG (view_config));
 
 	priv = view_config->priv;
-	
+
 	if (priv->view) {
 		g_object_unref (priv->view);
 		priv->view = NULL;
 	}
-	
+
 	for (l = priv->notifications; l; l = l->next)
 		calendar_config_remove_notification (GPOINTER_TO_UINT (l->data));
 
@@ -277,26 +257,20 @@ e_week_view_config_set_view (EWeekViewConfig *view_config, EWeekView *week_view)
 	/* If the new view is NULL, return right now */
 	if (!week_view)
 		return;
-	
+
 	priv->view = g_object_ref (week_view);
 
-	/* Time zone */
-	set_timezone (week_view);
-	
-	not = calendar_config_add_notification_timezone (timezone_changed_cb, view_config);
-	priv->notifications = g_list_prepend (priv->notifications, GUINT_TO_POINTER (not));
-	
 	/* Week start */
-	set_week_start (week_view);	
+	set_week_start (week_view);
 
 	not = calendar_config_add_notification_week_start_day (week_start_changed_cb, view_config);
 	priv->notifications = g_list_prepend (priv->notifications, GUINT_TO_POINTER (not));
 
 	/* 24 Hour format */
-	set_twentyfour_hour (week_view);	
+	set_twentyfour_hour (week_view);
 
 	not = calendar_config_add_notification_24_hour_format (twentyfour_hour_changed_cb, view_config);
-	priv->notifications = g_list_prepend (priv->notifications, GUINT_TO_POINTER (not));	
+	priv->notifications = g_list_prepend (priv->notifications, GUINT_TO_POINTER (not));
 
 	/* Show event end */
 	set_show_event_end (week_view);
