@@ -52,7 +52,6 @@
 #include "dialogs/task-editor.h"
 #include "misc/e-info-label.h"
 #include "e-util/e-error.h"
-#include "e-util/e-icon-factory.h"
 
 #define CREATE_TASK_ID               "task"
 #define CREATE_TASK_ASSIGNED_ID      "task-assigned"
@@ -1087,7 +1086,7 @@ create_component_view (TasksComponent *tasks_component)
 					     GTK_SHADOW_IN);
 	gtk_widget_show (selector_scrolled_window);
 
-	component_view->info_label = (EInfoLabel *)e_info_label_new("stock_task");
+	component_view->info_label = (EInfoLabel *)e_info_label_new("evolution-tasks");
 	e_info_label_set_info(component_view->info_label, _("Tasks"), "");
 	gtk_widget_show (GTK_WIDGET (component_view->info_label));
 
@@ -1208,6 +1207,7 @@ view_destroyed_cb (gpointer data, GObject *where_the_object_was)
 static GNOME_Evolution_ComponentView
 impl_createView (PortableServer_Servant servant,
 		 GNOME_Evolution_ShellView parent,
+		 CORBA_boolean select_item,
 		 CORBA_Environment *ev)
 {
 	TasksComponent *component = TASKS_COMPONENT (bonobo_object_from_servant (servant));
@@ -1323,7 +1323,7 @@ impl__get_userCreatableItems (PortableServer_Servant servant,
 
 	list->_buffer[0].id = CREATE_TASK_ID;
 	list->_buffer[0].description = _("New task");
-	list->_buffer[0].menuDescription = C_("New", "_Task");
+	list->_buffer[0].menuDescription = (char *) C_("New", "_Task");
 	list->_buffer[0].tooltip = _("Create a new task");
 	list->_buffer[0].menuShortcut = 't';
 	list->_buffer[0].iconName = "stock_task";
@@ -1331,7 +1331,7 @@ impl__get_userCreatableItems (PortableServer_Servant servant,
 
 	list->_buffer[1].id = CREATE_TASK_ASSIGNED_ID;
 	list->_buffer[1].description = _("New assigned task");
-	list->_buffer[1].menuDescription = C_("New", "Assigne_d Task");
+	list->_buffer[1].menuDescription = (char *) C_("New", "Assigne_d Task");
 	list->_buffer[1].tooltip = _("Create a new assigned task");
 	list->_buffer[1].menuShortcut = '\0';
 	list->_buffer[1].iconName = "stock_task";
@@ -1339,7 +1339,7 @@ impl__get_userCreatableItems (PortableServer_Servant servant,
 
 	list->_buffer[2].id = CREATE_TASK_LIST_ID;
 	list->_buffer[2].description = _("New task list");
-	list->_buffer[2].menuDescription = C_("New", "Tas_k list");
+	list->_buffer[2].menuDescription = (char *) C_("New", "Tas_k list");
 	list->_buffer[2].tooltip = _("Create a new task list");
 	list->_buffer[2].menuShortcut = '\0';
 	list->_buffer[2].iconName = "stock_todo";
