@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2008 Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -25,6 +25,7 @@
 #include <e-util/e-error.h>
 #include <mail/em-event.h>
 #include <mail/em-format-html-print.h>
+#include <mail/em-composer-utils.h>
 
 #include "misc/e-charset-picker.h"
 
@@ -339,6 +340,13 @@ action_send_options_cb (GtkAction *action,
 			"mail-composer:send-options-support", NULL);
 }
 
+static void
+action_new_message_cb (GtkAction *action,
+                        EMsgComposer *composer)
+{
+	em_utils_compose_new_message (NULL);
+}
+
 static void
 action_smime_encrypt_cb (GtkToggleAction *action,
                          EMsgComposer *composer)
@@ -522,6 +530,13 @@ static GtkActionEntry entries[] = {
 	  N_("Insert Send options"),
 	  G_CALLBACK (action_send_options_cb) },
 
+	{ "new-message",
+	  "mail-message-new",
+	  N_("New _Message"),
+	  "<Control>n",
+	  N_("Open New Message window"),
+	  G_CALLBACK (action_new_message_cb) },
+
 	/* Menus */
 
 	{ "charset-menu",
