@@ -7,6 +7,7 @@
 #define _EM_FORMAT_HTML_DISPLAY_H
 
 #include "mail/em-format-html.h"
+#include "widgets/misc/e-attachment-bar.h"
 
 typedef struct _EMFormatHTMLDisplay EMFormatHTMLDisplay;
 typedef struct _EMFormatHTMLDisplayClass EMFormatHTMLDisplayClass;
@@ -50,6 +51,10 @@ void em_format_html_display_set_caret_mode(EMFormatHTMLDisplay *efhd, gboolean s
 
 void em_format_html_display_set_search(EMFormatHTMLDisplay *efhd, int type, GSList *strings);
 void em_format_html_display_search(EMFormatHTMLDisplay *efhd);
+void em_format_html_display_search_with (EMFormatHTMLDisplay *efhd, char *word);
+void em_format_html_display_search_close (EMFormatHTMLDisplay *efhd);
+
+GtkWidget *em_format_html_get_search_dialog (EMFormatHTMLDisplay *efhd);
 
 void em_format_html_display_cut (EMFormatHTMLDisplay *efhd);
 void em_format_html_display_copy (EMFormatHTMLDisplay *efhd);
@@ -58,6 +63,7 @@ void em_format_html_display_paste (EMFormatHTMLDisplay *efhd);
 void em_format_html_display_zoom_in (EMFormatHTMLDisplay *efhd);
 void em_format_html_display_zoom_out (EMFormatHTMLDisplay *efhd);
 void em_format_html_display_zoom_reset (EMFormatHTMLDisplay *efhd);
+EAttachmentBar *em_format_html_display_get_bar (EMFormatHTMLDisplay *efhd);
 
 gboolean em_format_html_display_popup_menu (EMFormatHTMLDisplay *efhd);
 
