@@ -2,7 +2,7 @@
  *
  *  Authors: Philip Van Hoof <pvanhoof@gnome.org>
  *
- *  Copyright 2004 Novell, Inc. (www.novell.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of version 2 of the GNU General Public
@@ -22,13 +22,9 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <gtk/gtkfilechooser.h>
-#include <gtk/gtkfilechooserdialog.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkstock.h>
+
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <libedataserver/e-source.h>
 #include <libedataserverui/e-source-selector.h>
 #include <libecal/e-cal.h>
@@ -268,7 +264,7 @@ do_save_calendar_rdf (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSource
 			add_string_to_rdf (node, "uid",temp_constchar);
 
 			e_cal_component_get_summary (comp, &temp_comptext);
-			add_string_to_rdf (node, "summary",&temp_comptext?temp_comptext.value:NULL);
+			add_string_to_rdf (node, "summary", temp_comptext.value);
 
 			e_cal_component_get_description_list (comp, &temp_list);
 			add_list_to_rdf (node, "description", temp_list, ECALCOMPONENTTEXT);
