@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* e-shell.h
  *
- * Copyright (C) 2000  Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -124,6 +124,10 @@ void              e_shell_go_offline       (EShell       *shell,
 void              e_shell_go_online        (EShell       *shell,
 					    EShellWindow *action_window, GNOME_Evolution_ShellState shell_state);
 
+gboolean	e_shell_get_crash_recovery	(EShell *shell);
+void		e_shell_set_crash_recovery	(EShell *shell,
+						 gboolean crash_recovery);
+
 void  e_shell_send_receive  (EShell *shell);
 
 void  e_shell_show_settings  (EShell       *shell,
