@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* evolution-shell-component-utils.h
  *
- * Copyright (C) 2000, 2001 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -22,7 +22,7 @@
 #define __EVOLUTION_SHELL_COMPONENT_UTILS_H__
 
 #include <bonobo/bonobo-ui-component.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 #ifdef __cplusplus
 extern "C" {
