@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gal-view-instance.c
- * Copyright 2000, 2001, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors:
  *   Chris Lahey <clahey@ximian.com>
@@ -375,7 +375,7 @@ gal_view_instance_set_current_view_id (GalViewInstance *instance, const char *vi
 	g_return_if_fail (instance != NULL);
 	g_return_if_fail (GAL_IS_VIEW_INSTANCE (instance));
 
-	d(g_print("%s: view_id set to %s\n", G_GNUC_FUNCTION, view_id));
+	d(g_print("%s: view_id set to %s\n", G_STRFUNC, view_id));
 
 	if (instance->current_id && !strcmp (instance->current_id, view_id))
 		return;
@@ -488,7 +488,7 @@ view_item_cb (GtkWidget *widget,
 static void
 add_popup_radio_item (EPopupMenu *menu_item,
 		      gchar *title,
-		      GtkSignalFunc fn,
+		      GCallback fn,
 		      gpointer closure,
 		      gboolean value)
 {
