@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * e-gui-utils.c
- * Copyright 2000, 2001, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors:
  *   Miguel de Icaza <miguel@ximian.com>
@@ -33,7 +33,7 @@ void
 e_auto_kill_popup_menu_on_selection_done (GtkMenu *menu)
 {
 	g_return_if_fail (GTK_IS_MENU (menu));
-	
+
 	g_signal_connect (menu, "selection_done", G_CALLBACK (gtk_widget_destroy), menu);
 }
 
@@ -164,11 +164,11 @@ e_container_change_tab_order(GtkContainer *container, GList *widgets)
 	GList *list;
 	list = g_list_copy(widgets);
 	g_list_foreach(list, (GFunc) g_object_ref, NULL);
-	return gtk_signal_connect_full(GTK_OBJECT(container), "focus",
-				       GTK_SIGNAL_FUNC(e_container_change_tab_order_callback),
-				       NULL, list,
-				       e_container_change_tab_order_destroy_notify,
-				       FALSE, FALSE);
+	return g_signal_connect_data (container, "focus",
+				      G_CALLBACK(e_container_change_tab_order_callback),
+				      list,
+				      (GClosureNotify) e_container_change_tab_order_destroy_notify,
+				      0);
 }
 
 struct widgetandint {
